@@ -9,7 +9,7 @@ from omegaconf import OmegaConf
 
 import grams.inputs as I
 import sm.misc as M
-from grams.config import ROOT_DIR
+from grams.config import PKG_DIR, ROOT_DIR
 from grams.main import GRAMS
 from tqdm.auto import tqdm
 
@@ -51,7 +51,7 @@ class IOFile:
 )
 @click.option(
     "--cfg_file",
-    default=str(ROOT_DIR / "grams.yaml"),
+    default=str(PKG_DIR / "grams.yaml"),
     help="cfg_file contains configuration of GRAMS",
 )
 @click.option(
